@@ -1,6 +1,7 @@
 package Mojo::Webqq::Client;
 use strict;
 use Mojo::IOLoop;
+use Mojo::IOLoop::Delay;
 $Mojo::Webqq::Client::CLIENT_COUNT  = 0;
 
 use Mojo::Webqq::Client::Remote::_prepare_for_login;
@@ -31,9 +32,18 @@ sub run{
 sub multi_run{
     Mojo::IOLoop->singleton->start unless Mojo::IOLoop->singleton->is_running; 
 }
+sub steps {
+    my $self = shift;
+    Mojo::IOLoop::Delay->new(ioloop=>$self->ioloop)->steps(@_)->catch(sub {
+        my ($delay, $err) = @_;
+        $self->error("steps error: $err");
+    })->wait;
+    $self;
+}
 sub stop{
     my $self = shift;
     my $mode = shift || "auto";
+    return if $self->is_stop;
     $self->is_stop(1);
     $self->info("客户端停止运行");
     if($mode eq "auto"){
@@ -78,63 +88,100 @@ sub ready{
         }
     });   
     $self->interval(3600*4,sub{$self->data(+{})});
-    $self->interval(300,sub{
-        return if ref $self ne 'Mojo::Webqq';
+    $self->interval(900,sub{
         $self->debug("检查数据完整性...");
         for my $g ($self->groups){
             if(not defined $g->{_client}){
                 $g->{_client} = $self;
-                $self->warn("群对象(" . $g->gid . ")数据异常, 已尝试修复");
+                $self->warn("群对象[ " . $g->gname . " ]数据异常, 已尝试修复");
             }
+            if(!defined $g->gnumber){
+                $self->warn("群对象[ " . $g->gname . " ]扩展数据异常, 已尝试修复");
+                $self->update_group_ext($g,is_blocking=>0,is_update_group_member_ext=>1);
+            }
+            my $ext_count = 0;
+            my $member_count = 0;
             for my $m ($g->members){
+                $member_count++;
                 if(not defined $m->{_client}){
                     $m->{_client} = $self;
-                    $self->warn("群成员对象(". $m->id . ")数据异常, 已尝试修复");
+                    $self->warn("群成员对象[ ". $m->id . "|". $g->gname . " ]数据异常, 已尝试修复");
                 }
+                $ext_count++ if defined $g->{gnumber} and defined $m->{qq};
+            }
+            if(defined $g->{gnumber} and $member_count>0 and $ext_count==0){
+                $self->warn("群对象[ " . $g->gname . " ]成员扩展数据异常，已尝试修复");
+                $self->update_group_member_ext($g,is_blocking=>0);
+            }
+            if(defined $g->{gnumber} and $member_count>0 and $ext_count>0 and $ext_count<$member_count){
+                $self->debug("群对象[ " . $g->gname . " ]成员扩展数据完整度: $ext_count/$member_count");
             }
         } 
         for my $d ($self->discusss){
             if(not defined $d->{_client}){
                 $d->{_client} = $self;
-                $self->warn("讨论组对象(" . $d->did . ")数据异常, 已尝试修复");
+                $self->warn("讨论组对象[ " . $d->displayname . " ]数据异常, 已尝试修复");
             }
             for my $m ($d->members){
                 if(not defined $m->{_client}){
                     $m->{_client} = $self;
-                    $self->warn("讨论组成员对象(". $m->id . ")数据异常, 已尝试修复");
+                    $self->warn("讨论组成员对象[ ". $m->displayname . "|" . $d->displayname . " ]数据异常, 已尝试修复");
                 }
             }
         }
+        my $ext_count = 0;
+        my $friend_count = 0;
         for my $f ($self->friends){
+            $friend_count++;
             if(not defined $f->{_client}){
                 $f->{_client} = $self;
-                $self->warn("好友对象(" . $f->id . ")数据异常, 已尝试修复");
+                $self->warn("好友对象[ " . $f->displayname . " ]数据异常, 已尝试修复");
             }
-        }        
+            $ext_count++ if defined $f->{qq};
+        }
+        if($friend_count>0 and $ext_count == 0){
+            $self->warn("好友扩展数据异常，已尝试修复");
+            $self->update_friend_ext(is_blocking=>0);
+        }
+        if($friend_count>0 and $ext_count >0 and $ext_count<$friend_count){
+            $self->debug("好友扩展数据完整度: $ext_count/$friend_count");
+        }
+        
     });
     $self->interval(600,sub{
         return if $self->is_stop;
-        $self->update_group;
+        return if not $self->is_update_group;
+        $self->update_group(is_blocking=>0,is_update_group_ext=>0,is_update_group_member=>1,is_update_group_member_ext=>0);
     });
 
     $self->timer(60,sub{
         $self->interval(600,sub{
             return if $self->is_stop;
-            $self->update_discuss;    
+            return if not $self->is_update_discuss;
+            $self->update_discuss(is_blocking=>0,is_update_discuss_member=>1);    
         });
     });
 
     $self->timer(60+60,sub{
         $self->interval(600,sub{
             return if $self->is_stop;
-            $self->update_friend;
+            return if not $self->is_update_friend;
+            $self->update_friend(is_blocking=>0,is_update_friend_ext=>0);
         });
     });
+
+    $self->timer(60+60+60,sub{
+        $self->interval(600,sub{
+            return if $self->is_stop;
+            return if not $self->is_update_user;
+            $self->update_user(is_blocking=>0);
+        });
+    });
+
     #接收消息
     $self->on(poll_over=>sub{ my $self = $_[0];$self->timer(1,sub{$self->_recv_message()}) } );
     $self->info("开始接收消息...\n");
     $self->_recv_message();
-    $Mojo::Webqq::Client::CLIENT_COUNT++;
     $self->is_ready(1);
     $self->emit("ready");
 }
@@ -265,10 +312,10 @@ sub login {
             $self->qrcode_count(0);
             $self->info("帐号(" . $self->qq . ")登录成功");
             $self->update_user;
-            $self->update_friend;
-            $self->update_group;
-            $self->update_discuss;
-            $self->update_recent;
+            $self->update_friend(is_blocking=>1,is_update_friend_ext=>1) if $self->is_init_friend;
+            $self->update_group(is_blocking=>1,is_update_group_ext=>1,is_update_group_member_ext=>0,is_update_group_member=>0)  if $self->is_init_group;
+            $self->update_discuss(is_blocking=>1,is_update_discuss_member=>0) if $self->is_init_discuss;
+            $self->update_recent(is_blocking=>1) if $self->is_init_recent;
             $self->emit("login");
         }
     };
